summaryrefslogtreecommitdiffstats
path: root/Lib/test/libregrtest/runtests.py
diff options
context:
space:
mode:
Diffstat (limited to 'Lib/test/libregrtest/runtests.py')
-rw-r--r--Lib/test/libregrtest/runtests.py5
1 files changed, 2 insertions, 3 deletions
diff --git a/Lib/test/libregrtest/runtests.py b/Lib/test/libregrtest/runtests.py
index 893b311..bfed1b4 100644
--- a/Lib/test/libregrtest/runtests.py
+++ b/Lib/test/libregrtest/runtests.py
@@ -8,7 +8,7 @@ from typing import Any
from test import support
from .utils import (
StrPath, StrJSON, TestTuple, FilterTuple, FilterDict)
class JsonFileType:
@@ -72,8 +72,7 @@ class RunTests:
tests: TestTuple
fail_fast: bool
fail_env_changed: bool
- match_tests: FilterTuple | None
- ignore_tests: FilterTuple | None
+ match_tests: TestFilter
match_tests_dict: FilterDict | None
rerun: bool
forever: bool
@@ -8,7 +8,7 @@ from typing import Any
from test import support
from .utils import (
- StrPath, StrJSON, TestTuple, FilterTuple, FilterDict)
+ StrPath, StrJSON, TestTuple, TestFilter, FilterTuple, FilterDict)
class JsonFileType: